#include "simulat.h"
#include <stdio.h>
#include "nrutil.h"
#include "file.h"

extern int NN,NL;

void READ_NN_NL(FILE **fptr)
{
	if((*fptr=fopen("rxrdata","rt"))!=NULL)
		fscanf(*fptr,"%d %d\n",&NN,&NL);
	else 
		perror("couldn't open input file 'RXRDATA'");
}			

void DECLARE1(float **mass,float **enth,float **spech,float **vol,float **temp,float **press,float **heat,
			float **rho,float **dpdt,float **dmdt,float **dhdt,float **dtempdt,float **hold,float **G1temp,
			float **G2temp,float **c1,float **c2,float **voi,float **qual)
{
	/* declaration of vectors and matrices to be of size specified by file data */

	*mass=vector(1,NN);
	*enth=vector(1,NN);
	*spech=vector(1,NN);
	*vol=vector(1,NN);
	*temp=vector(1,NN);
	*press=vector(1,NN);
	*heat=vector(1,NN);
	*rho=vector(1,NN);
	*dpdt=vector(1,NN);
	*dmdt=vector(1,NN);
	*dhdt=vector(1,NN);
	*dtempdt=vector(1,NN);
	*hold=vector(1,NN);
	*G1temp=vector(1,NN);
	*G2temp=vector(1,NN);
	*c1=vector(1,NN);
	*c2=vector(1,NN);
	*voi=vector(1,NN);
	*qual=vector(1,NN);
}

void DECLARE2(float **area,float **len,float **dia,float **dz,float **dppump,float **k,float **loss,
			float **w,float **den,float **work,float **bwmat,float **bhmat,float **bpmat,float **bmmat,
			float **term2)
{
	*area=vector(1,NL);
	*len=vector(1,NL);
	*dia=vector(1,NL);
	*dz=vector(1,NL);
	*dppump=vector(1,NL);
	*k=vector(1,NL);
	*loss=vector(1,NL);
	*w=vector(1,NL);
	*den=vector(1,NL);
	*work=vector(1,NL);
	
	*bwmat=vector(1,NL);
	*bhmat=vector(1,NN);
	*bpmat=vector(1,NN);	
	*bmmat=vector(1,NN);
	*term2=vector(1,NL);
}

void DECLARE3(int **indx,int **iup,int **idown,int **ifrom,float ***mwmat,float ***hwmat,float ***pwmat,
			float ***wpmat,float ***wwmat,float ***matran,float ***term1)
{
	*mwmat=matrix(1,NN,1,NL);
	*hwmat=matrix(1,NN,1,NL);
	*pwmat=matrix(1,NN,1,NL);
	*wpmat=matrix(1,NL,1,NN);
	*wwmat=matrix(1,NL,1,NL);
	*matran=matrix(1,NN,1,NN);
	*term1=matrix(1,NL,1,NL);
	*indx=ivector(1,NL);
	*iup=ivector(1,NL);
	*idown=ivector(1,NL);
	*ifrom=ivector(1,NL);
}

void READ_INPUT(FILE *fptr,float *tfin,float *dtmin,float *dtmax,float *ts,float *tp,float *terr,
				float *pscale,float *adj,int *ifull,int *nmax,float *vol,float *press,float *spech,
				float *area,float *len,float *dia,float *dz,float *loss,float *w,int *iup,int *idown,
				int *ifrom)
{
	int i;
	
	/* read in the contents of the data file */

	fscanf(fptr,"%f %f %f\n",tfin,dtmin,dtmax);
	fscanf(fptr,"%f %f\n",ts,tp);
	fscanf(fptr,"%f %f %f\n\n",terr,pscale,adj);
	fscanf(fptr,"%d %d\n",ifull,nmax);
	fscanf(fptr,"%*s\n");

	/* read in node quantities */
	
	for(i=1;i<=NN;i++)
		fscanf(fptr,"%*d %f %f %f %*s\n",&vol[i],&press[i],&spech[i]);
	
	fscanf(fptr,"%*s\n");

	/* read in link quantities */
	
	for(i=1;i<=NL;i++)
		fscanf(fptr,"%d %d %f %f %f %f %f %f\n",&iup[i],&idown[i],&area[i],
			&len[i],&dia[i],&dz[i],&loss[i],&w[i]);
					
	fclose(fptr);
}

void INIT_OUTPUT(FILE **fptr,int ifull)
{
	/* open up output file and print method to be used at beginning */
	
	if((*fptr=fopen("rxrout","w"))!=NULL)
	{
		if(ifull==0)
			fprintf(*fptr,"semi-implicit method\n\n");
		else
			fprintf(*fptr,"fully-implicit method\n\n");
	}			
	else
		perror("couldn't open output file 'RXROUT'");
}		

void PRINTOUT(FILE *fptr,float *w,float *press,float *temp,float *rho,float *spech,float *voi,
				float t,float dtlast,float tfin,float *tprint,float tp)
{
	int i;

	fprintf(fptr,"%6.2f ",t);
	
	for(i=1;i<=NL;i++) fprintf(fptr,"%6.1f ",w[i]);
	
	fprintf(fptr,"\n");
	
	*tprint=*tprint+tp;
}
      										
